@@ -42,10 +42,10 @@ extern char *get_mandb_manpath (void);
 extern char *get_catpath (const char *name, int cattype);
 extern int is_global_mandir (const char *dir);
 extern void read_config_file (int optional);
-#ifdef SECURE_MAN_UID
+#ifdef MAN_OWNER
 extern const char *get_def (const char *thing, const char *def);
-#else /* !SECURE_MAN_UID */
+#else /* !MAN_OWNER */
 #define get_def(thing, def) get_def_user ((thing), (def))
-#endif /* SECURE_MAN_UID */
+#endif /* MAN_OWNER */
 extern const char *get_def_user (const char *thing, const char *def);
 extern const char **get_sections (void);
